package com.ynet.life.sujrb.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Random;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.Region;

/* loaded from: com_ynet_life_sujrb_action.jar:com/ynet/life/sujrb/action/CreditLoanDownloadAction.class */
public class CreditLoanDownloadAction extends LifeAction {
    private static final String FIELD_SEPERATOR = "||";
    private String iCollName;

    public String execute(Context ctx) throws GENEException {
        try {
            ctx.terminate();
            List recordList = initFromContext(ctx, "classReportList");
            String filePathName = getFileName("xls", "creditLoanReport");
            writeToFile(recordList, filePathName);
            ctx.put("downloadFile", filePathName);
            return "0";
        } catch (Exception ex) {
            Trace.logError("LifeAction", "RZPT90001:报表下载处理出错", ex);
            throw new TranFailException("RZPT90001", "报表下载处理出错", false);
        }
    }

    private void writeToFile(List recordList, String filePathName) throws TranFailException {
        HSSFWorkbook workBook = new HSSFWorkbook();
        HSSFSheet sheet = workBook.createSheet();
        HSSFFont font = workBook.createFont();
        font.setFontName("黑体");
        font.setColor((short) 8);
        font.setFontHeight((short) 300);
        HSSFFont titleFont = workBook.createFont();
        titleFont.setFontName("黑体");
        titleFont.setColor((short) 8);
        titleFont.setFontHeight((short) 250);
        HSSFCellStyle titleCellStyle = workBook.createCellStyle();
        titleCellStyle.setAlignment((short) 2);
        titleCellStyle.setVerticalAlignment((short) 1);
        titleCellStyle.setFont(titleFont);
        HSSFCellStyle cellConStyle = workBook.createCellStyle();
        cellConStyle.setAlignment((short) 2);
        HSSFCellStyle cellStyle = workBook.createCellStyle();
        cellStyle.setAlignment((short) 2);
        cellStyle.setFont(font);
        sheet.addMergedRegion(new Region(0, (short) 0, 0, (short) recordList.size()));
        HSSFRow row = sheet.createRow(0);
        createCell(row, 0, "信保贷业务逐月进度统计", cellStyle);
        HSSFRow rowOne = sheet.createRow(1);
        HSSFRow rowTwo = sheet.createRow(2);
        createCell(rowTwo, 0, "当月放款笔数", cellConStyle);
        HSSFRow rowThree = sheet.createRow(3);
        createCell(rowThree, 0, "当月放款金额(万元)", cellConStyle);
        HSSFRow rowFour = sheet.createRow(4);
        createCell(rowFour, 0, "放款笔数环比", cellConStyle);
        HSSFRow rowFive = sheet.createRow(5);
        createCell(rowFive, 0, "放款金额环比", cellConStyle);
        int colIndex = 1;
        sheet.setColumnWidth(0, 5000);
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            Map record = (Map) iterator.next();
            sheet.setColumnWidth(colIndex, 3000);
            createCell(rowOne, colIndex, record.get("date").toString(), titleCellStyle);
            createCell(rowTwo, colIndex, record.get("loaCount").toString(), cellConStyle);
            createCell(rowThree, colIndex, record.get("loaAmt").toString(), cellConStyle);
            createCell(rowFour, colIndex, record.get("loaCountRate").toString(), cellConStyle);
            createCell(rowFive, colIndex, record.get("loaAmtRate").toString(), cellConStyle);
            colIndex++;
        }
        FileOutputStream fileOut = null;
        try {
            try {
                fileOut = new FileOutputStream(filePathName);
                workBook.write(fileOut);
                try {
                    fileOut.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (IOException ex2) {
                Trace.logError("LifeFile", "文件写入失败", ex2);
                throw new TranFailException("EBLN0000", "文件写入失败", ex2);
            }
        } catch (Throwable th) {
            if (fileOut != null) {
                try {
                    fileOut.close();
                } catch (IOException ex3) {
                    Trace.logError("LifeFile", "I/O异常", ex3);
                    throw new TranFailException("EBLN0000", "I/O异常", ex3);
                }
            }
            throw th;
        }
    }

    private void createCell(HSSFRow row, int index, String content, HSSFCellStyle cellStyle) {
        HSSFCell cell = row.createCell(index);
        cell.setCellValue(new HSSFRichTextString(content));
        cell.setCellStyle(cellStyle);
    }

    private String getLanguage(Context context) {
        if (context == null) {
            return null;
        }
        String language = null;
        try {
            language = (String) context.getDataValue("session_language");
        } catch (GENEException unused) {
        }
        return language;
    }

    protected String getFileName(String fileType, String fileName) throws TranFailException {
        String rootPath = LifeStandard.getSelfDefineSettingsValue("tempDownloadDir");
        String folder = String.valueOf(LifeStandard.getServerTime("yyyyMMdd")) + LifeFile.DIR_SEPARATOR;
        LifeFile.makeMultiDirectory(rootPath, folder);
        String filePathName = String.valueOf(LifeStandard.getServerTime("HHmmssSSS")) + new Random().nextInt(1000) + fileName + '.' + fileType;
        return String.valueOf(rootPath) + folder + filePathName;
    }

    public List initFromContext(Map context, String iCollName) throws TranFailException {
        List recordList = new ArrayList();
        for (Map kcoll : (List) context.get(iCollName)) {
            recordList.add(kcoll);
        }
        return recordList;
    }
}
